from setuptools import setup

setup(name='js_prob_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['js_prob_distributions'],
      author='Jatin Singh',
      zip_safe=False)
